@@ -1,7 +1,7 @@
 import pathlib
 import configparser
 
-__version__ = '0.18.1'
+__version__ = '0.20.8'
 
 # Load the configuration settings.
 HERE = pathlib.Path(__file__).parent.resolve()
@@ -45,10 +45,9 @@ from asilib.analysis.equal_area import equal_area
 from asilib.imager import Imager
 from asilib.imagers import Imagers
 from asilib.conjunction import Conjunction
-from asilib.asi.themis import themis, themis_info, themis_skymap
-from asilib.asi.rego import rego, rego_info, rego_skymap
 
 __all__ = [
     'Imager',
+    'Imagers',
     'Conjunction',
-]  # So Sphinx shortens the name. See https://stackoverflow.com/a/66743762
+]  # So Sphinx shortens the name. See https://stackoverflow.com/a/31594545
