@@ -20,6 +20,7 @@ import asilib
 import asilib.asi.themis as themis
 import asilib.utils as utils
 import asilib.io.download as download
+import asilib.skymap
 
 
 pgm_base_url = 'https://data.phys.ucalgary.ca/sort_by_project/GO-Canada/REGO/stream0/'
@@ -32,6 +33,7 @@ def rego(
     time: utils._time_type = None,
     time_range: utils._time_range_type = None,
     alt: int = 110,
+    custom_alt: bool = False,
     redownload: bool = False,
     missing_ok: bool = True,
     load_images: bool = True,
@@ -40,6 +42,10 @@ def rego(
     """
     Create an Imager instance with the REGO ASI images and skymaps.
 
+    Redline Emission Geospace Observatory (REGO) data is courtesy of Space Environment Canada (space-environment.ca). Use of the data must adhere to the rules of the road for that dataset. Please see below for the required data acknowledgement. Any questions about the REGO instrumentation or data should be directed to the University of Calgary, Emma Spanswick (elspansw@ucalgary.ca) and/or Eric Donovan (edonovan@ucalgary.ca).
+
+    “The Redline Emission Geospace Observatory (REGO) is a joint Canada Foundation for Innovation and Canadian Space Agency project developed by the University of Calgary. REGO is operated and maintained by Space Environment Canada with the support of the Canadian Space Agency (CSA) [23SUGOSEC].”
+
     Parameters
     ----------
     location_code: str
@@ -52,6 +58,12 @@ def rego(
         the ASI data time interval.
     alt: int
         The reference skymap altitude, in kilometers.
+    custom_alt: bool
+        If True, asilib will calculate (lat, lon) skymaps assuming a spherical Earth. Otherwise, it will use the official skymaps (Courtesy of University of Calgary).
+
+        .. note::
+        
+            The spherical model of Earth's surface is less accurate than the oblate spheroid geometrical representation. Therefore, there will be a small difference between these and the official skymaps.
     redownload: bool
         If True, will download the data from the internet, regardless of
         wether or not the data exists locally (useful if the data becomes
@@ -76,7 +88,7 @@ def rego(
     >>> # Plot a single image.
     >>> from datetime import datetime
     >>> import matplotlib.pyplot as plt
-    >>> import asilib
+    >>> import asilib.asi
     >>> import asilib.map
     >>> location_code = 'RANK'
     >>> time = datetime(2017, 9, 15, 2, 34, 0)
@@ -84,7 +96,7 @@ def rego(
     >>> fig = plt.figure(figsize=(10, 6))
     >>> ax = fig.add_subplot(121)
     >>> bx = asilib.map.create_map(fig_ax=(fig, 122), lon_bounds = (-102, -82), lat_bounds = (58, 68))
-    >>> asi = asilib.rego(location_code, time=time, alt=alt_km)
+    >>> asi = asilib.asi.rego(location_code, time=time, alt=alt_km)
     >>> asi.plot_fisheye(ax=ax)
     >>> asi.plot_map(ax=bx)
     >>> plt.tight_layout()
@@ -145,15 +157,27 @@ def rego(
     else:
         _time = time_range[0]
     _skymap = rego_skymap(location_code, _time, redownload=redownload)
-    alt_index = np.where(_skymap['FULL_MAP_ALTITUDE'] / 1000 == alt)[0]
-    assert (
-        len(alt_index) == 1
-    ), f'{alt} km is not in the valid skymap altitudes: {_skymap["FULL_MAP_ALTITUDE"]/1000} km.'
-    alt_index = alt_index[0]
+    
+    if custom_alt==False:
+        alt_index = np.where(_skymap['FULL_MAP_ALTITUDE'] / 1000 == alt)[0] #Compares the altitudes versus the ones provided by default and chooses the correct index that correlates to the chosen alitudes
+        assert (
+            len(alt_index) == 1
+        ), f'{alt} km is not in the valid skymap altitudes: {_skymap["FULL_MAP_ALTITUDE"]/1000} km. If you want a custom altitude with less percision, please use the custom_alt keyword'
+        alt_index = alt_index[0]
+        lat=_skymap['FULL_MAP_LATITUDE'][alt_index, :, :] #selects lat lon coordinates from data provided in skymap
+        lon=_skymap['FULL_MAP_LONGITUDE'][alt_index, :, :]
+    else:
+        lat,lon = asilib.skymap.geodetic_skymap( #Spherical projection for lat lon coordinates
+            (float(_skymap['SITE_MAP_LATITUDE']), float(_skymap['SITE_MAP_LONGITUDE']), float(_skymap['SITE_MAP_ALTITUDE']) / 1e3),
+            _skymap['FULL_AZIMUTH'],
+            _skymap['FULL_ELEVATION'],
+            alt
+            )
+
     skymap = {
-        'lat': _skymap['FULL_MAP_LATITUDE'][alt_index, :, :],
-        'lon': _skymap['FULL_MAP_LONGITUDE'][alt_index, :, :],
-        'alt': _skymap['FULL_MAP_ALTITUDE'][alt_index] / 1e3,
+        'lat': lat,
+        'lon': lon,
+        'alt': alt,
         'el': _skymap['FULL_ELEVATION'],
         'az': _skymap['FULL_AZIMUTH'],
         'path': _skymap['PATH'],
