@@ -20,6 +20,7 @@ import themis_imager_readfile
 import asilib
 import asilib.utils as utils
 import asilib.io.download as download
+import asilib.skymap
 
 
 pgm_base_url = 'https://data.phys.ucalgary.ca/sort_by_project/THEMIS/asi/stream0/'
@@ -32,6 +33,7 @@ def themis(
     time: utils._time_type = None,
     time_range: utils._time_range_type = None,
     alt: int = 110,
+    custom_alt: bool = False,
     redownload: bool = False,
     missing_ok: bool = True,
     load_images: bool = True,
@@ -56,6 +58,12 @@ def themis(
         If True, will download the data from the internet, regardless of
         wether or not the data exists locally (useful if the data becomes
         corrupted).
+    custom_alt: bool
+        If True, asilib will calculate (lat, lon) skymaps assuming a spherical Earth. Otherwise, it will use the official skymaps (Courtesy of University of Calgary).
+
+        .. note::
+        
+            The spherical model of Earth's surface is less accurate than the oblate spheroid geometrical representation. Therefore, there will be a small difference between these and the official skymaps.
     missing_ok: bool
         Wether to allow missing data files inside time_range (after searching
         for them locally and online).
@@ -65,6 +73,7 @@ def themis(
     imager: asilib.Imager
         Controls what Imager instance to return, asilib.Imager by default. This
         parameter is useful if you need to subclass asilib.Imager.
+        
 
     Returns
     -------
@@ -123,15 +132,27 @@ def themis(
     else:
         _time = time_range[0]
     _skymap = themis_skymap(location_code, _time, redownload)
-    alt_index = np.where(_skymap['FULL_MAP_ALTITUDE'] / 1000 == alt)[0]
-    assert (
-        len(alt_index) == 1
-    ), f'{alt} km is not in the valid skymap altitudes: {_skymap["FULL_MAP_ALTITUDE"]/1000} km.'
-    alt_index = alt_index[0]
+
+    if custom_alt==False:
+        alt_index = np.where(_skymap['FULL_MAP_ALTITUDE'] / 1000 == alt)[0] #Compares the altitudes versus the ones provided by default and chooses the correct index that correlates to the chosen alitudes
+        assert (
+            len(alt_index) == 1
+        ), f'{alt} km is not in the valid skymap altitudes: {_skymap["FULL_MAP_ALTITUDE"]/1000} km. If you want a custom altitude with less percision, please use the custom_alt keyword'
+        alt_index = alt_index[0]
+        lat=_skymap['FULL_MAP_LATITUDE'][alt_index, :, :] #selects lat lon coordinates from data provided in skymap
+        lon=_skymap['FULL_MAP_LONGITUDE'][alt_index, :, :]
+    else:
+        lat,lon = asilib.skymap.geodetic_skymap( #Spherical projection for lat lon coordinates
+            (float(_skymap['SITE_MAP_LATITUDE']), float(_skymap['SITE_MAP_LONGITUDE']), float(_skymap['SITE_MAP_ALTITUDE']) / 1e3),
+            _skymap['FULL_AZIMUTH'],
+            _skymap['FULL_ELEVATION'],
+            alt
+            )
+
     skymap = {
-        'lat': _skymap['FULL_MAP_LATITUDE'][alt_index, :, :],
-        'lon': _skymap['FULL_MAP_LONGITUDE'][alt_index, :, :],
-        'alt': _skymap['FULL_MAP_ALTITUDE'][alt_index] / 1e3,
+        'lat': lat,
+        'lon': lon,
+        'alt': alt,
         'el': _skymap['FULL_ELEVATION'],
         'az': _skymap['FULL_AZIMUTH'],
         'path': _skymap['PATH'],
