@@ -1,6 +1,7 @@
 import importlib
 from typing import Tuple, Union, Callable
 import warnings
+import functools
 
 import numpy as np
 import pandas as pd
@@ -129,10 +130,10 @@ class Conjunction:
         return df
 
     def intensity(
-        self, box: Tuple[float, float] = None, box_op: Callable = np.nanmean
+        self, box: Tuple[float, float] = None, box_op: Callable = None
     ) -> np.ndarray:
         """
-        Calculate the auroral intensity near the satellite's footprint.
+        Calculate the auroral intensity near the satellite's footprint at the ASI time stamps.
 
         Parameters
         ----------
@@ -145,7 +146,8 @@ class Conjunction:
         box_op: Callable
             The function to apply to the auroral intensity in the box surrounding the footprint. Since
             it must operate on the mask array that :py:meth:`~asilib.Conjunction.equal_area()` produces,
-            the ``box_op`` function must work with (i.e., ignore) ``np.nan`` values.
+            the ``box_op`` function must work with (i.e., ignore) ``np.nan`` values. If None, the function
+            is np.nanmean() summed over the x-y pixels.
 
         Returns
         -------
@@ -161,7 +163,20 @@ class Conjunction:
             similar results, but discrepancies may arise if the skymap (az, el) and (lat, lon) mapping arrays are
             mismatched. This is the case for some of the THEMIS ASIs right after they were deployed.
         """
-        _intensity = np.nan * np.zeros(self.sat.shape[0], dtype=float)
+        self.interp_sat()  # Need the sat time stamps and coordinates to match the Imager's.
+        
+        if len(self.imager.meta['resolution']) == 2: # white-light intensity
+            _intensity = np.nan * np.zeros(self.sat.shape[0], dtype=float)
+        elif len(self.imager.meta['resolution']) == 3: # RGB intensity
+            _intensity = np.nan * np.zeros(
+                (self.sat.shape[0], self.imager.meta['resolution'][-1]), dtype=float
+                )
+        else:
+            raise ValueError(
+                f'Imager resolution must be 2d or 3d, not {len(self.imager.meta["resolution"])}d.'
+                )
+
+            
         if box is None:  # Nearest pixel to footprint
             _, azel_pixels = self.map_azel()
             for i, ((_, image), pixels) in enumerate(zip(self.imager, azel_pixels)):
@@ -170,6 +185,7 @@ class Conjunction:
                 # The ::-1 b/c pixels are in plotting (not indexing) order.
                 _intensity[i] = image[int(pixels[1]), int(pixels[0])]
         else:  # Area around footprint
+            box_op = functools.partial(np.nanmean, axis=(0,1))  # Sum only the x-y pixels.
             # equal_area_gen() is slower than using equal_area(), but this plays nice with memory.
             gen = self.equal_area_gen(box=box)
             for i, ((_, image), mask) in enumerate(zip(self.imager, gen)):
@@ -178,7 +194,7 @@ class Conjunction:
 
     def interp_sat(self):
         """
-        Interpolate the satellite timestamps and LLA at the imager timestamps.
+        Interpolate the satellite timestamps and LLA to imager timestamps.
         """
         imager_times, _ = self.imager.data
         numeric_imager_times = date2num(imager_times)
@@ -257,7 +273,6 @@ class Conjunction:
         ImportError
             If IRBEM can't be imported.
         """
-        # TODO: Add tests
         if importlib.util.find_spec('IRBEM') is None:
             raise ImportError(
                 "IRBEM can't be imported. This is a required dependency for asilib.lla2footprint()"
@@ -271,14 +286,15 @@ class Conjunction:
         m = IRBEM.MagFields(kext=b_model)  # Initialize the IRBEM model.
 
         # Loop over every set of satellite coordinates.
-        for i, (time, (lat, lon, alt)) in enumerate(self.sat.iterrows()):
-            X = {'datetime': time, 'x1': alt, 'x2': lat, 'x3': lon}
+        for i, (_time, (_lat, _lon, _alt)) in enumerate(self.sat.iterrows()):
+            X = {'datetime': _time, 'x1': _alt, 'x2': _lat, 'x3': _lon}
             m_output = m.find_foot_point(X, maginput, alt, hemisphere)
             magnetic_footprint[i, :] = m_output['XFOOT']
         # Map from IRBEM's (alt, lat, lon) -> (lat, lon, alt)
         # magnetic_footprint[:, [2, 0, 1]] = magnetic_footprint[:, [0, 1, 2]]
         self.sat.loc[:, ['alt', 'lat', 'lon']] = magnetic_footprint
-        return
+        self.sat[self.sat['lat'] == -1E31] = np.nan
+        return self.sat
 
     def map_azel(self, min_el=0) -> Tuple[np.ndarray, np.ndarray]:
         """
@@ -430,6 +446,10 @@ class Conjunction:
 
                 masked_box_len = len(idx_box[0])
                 if masked_box_len:
+                    row_below_hozizon = np.any(idx_box[0] >= mask.shape[0]) or np.any(idx_box[0] == 0)
+                    col_below_hozizon = np.any(idx_box[1] >= mask.shape[1]) or np.any(idx_box[1] == 0)
+                    if row_below_hozizon or col_below_hozizon:
+                        break  # The footprint is at the horizon.
                     mask[idx_box[0], idx_box[1]] = 1
                 else:
                     multiplier += step
@@ -483,7 +503,7 @@ class Conjunction:
         dlon_rads = 2 * np.arcsin(numerator / denominator)
         return np.rad2deg(dlon_rads)
 
-    def _nearest_pixel(self, azel, n_max_vectorize=10_000) -> np.ndarray:
+    def _nearest_pixel(self, azel, n_max_vectorize=1_000) -> np.ndarray:
         """
         Locate the nearest ASI skymap (x, y) pixel indices.
 
