@@ -86,6 +86,7 @@ class Imager:
         color_map: str = None,
         color_bounds: List[float] = None,
         color_norm: str = None,
+        color_brighten: bool = True,
         azel_contours: bool = False,
         azel_contour_color: str = 'yellow',
         cardinal_directions: str = 'NE',
@@ -109,7 +110,11 @@ class Imager:
         color_norm: str
             Set the 'lin' (linear) or 'log' (logarithmic) color normalization. If color_norm=None,
             the color normalization will be taken from the ASI array (if specified), and if not
-            specified it will default to logarithmic.
+            specified it will default to logarithmic. The norm is not applied to RGB images (see 
+            `matplotlib.pyplot.imshow <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html>`_)
+        color_brighten: bool
+            If True, scales the RGB intensities from min(image)-max(image) to 0-1 range. This 
+            results in brighter colors. This is only applied to RGB images.
         azel_contours: bool
             Superpose azimuth and elevation contours on or off.
         azel_contour_color: str
@@ -160,6 +165,11 @@ class Imager:
 
         color_map, color_norm = self._plot_params(image, color_bounds, color_map, color_norm)
 
+        if len(self.meta['resolution']) == 3:  # tests if rgb
+            image = self._rgb_replacer(image)
+            if color_brighten:
+                image = image / np.max(image)
+
         im = ax.imshow(image, cmap=color_map, norm=color_norm, origin="lower")
         if label:
             self._add_fisheye_label(time, ax)
@@ -189,7 +199,11 @@ class Imager:
         color_norm: str
             Set the 'lin' (linear) or 'log' (logarithmic) color normalization. If color_norm=None,
             the color normalization will be taken from the ASI array (if specified), and if not
-            specified it will default to logarithmic.
+            specified it will default to logarithmic. The norm is not applied to RGB images (see 
+            `matplotlib.pyplot.imshow <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html>`_)
+        color_brighten: bool
+            If True, scales the RGB intensities from min(image)-max(image) to 0-1 range. This 
+            results in brighter colors. This is only applied to RGB images.
         azel_contours: bool
             Superpose azimuth and elevation contours on or off.
         azel_contour_color: str
@@ -246,11 +260,13 @@ class Imager:
         color_map: str = None,
         color_bounds: List[float] = None,
         color_norm: str = None,
+        color_brighten: bool = True,
         azel_contours: bool = False,
         azel_contour_color: str = 'yellow',
         cardinal_directions: str = 'NE',
         origin: tuple = (0.8, 0.1),
         movie_container: str = 'mp4',
+        animation_save_dir: Union[pathlib.Path, str]=None,
         ffmpeg_params={},
         overwrite: bool = False,
     ) -> Generator[
@@ -281,7 +297,11 @@ class Imager:
         color_norm: str
             Set the 'lin' (linear) or 'log' (logarithmic) color normalization. If color_norm=None,
             the color normalization will be taken from the ASI array (if specified), and if not
-            specified it will default to logarithmic.
+            specified it will default to logarithmic. The norm is not applied to RGB images (see 
+            `matplotlib.pyplot.imshow <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html>`_)
+        color_brighten: bool
+            If True, scales the RGB intensities from min(image)-max(image) to 0-1 range. This 
+            results in brighter colors. This is only applied to RGB images.
         azel_contours: bool
             Superpose azimuth and elevation contours on or off.
         azel_contour_color: str
@@ -344,8 +364,12 @@ class Imager:
 
         # Create the animation directory inside asilib.config['ASI_DATA_DIR'] if it does
         # not exist.
+        if animation_save_dir is None:
+            _path = asilib.config['ASI_DATA_DIR']
+        else:
+            _path = animation_save_dir
         image_save_dir = pathlib.Path(
-            asilib.config['ASI_DATA_DIR'],
+            _path,
             'animations',
             'images',
             f'{self.file_info["time_range"][0].strftime("%Y%m%d_%H%M%S")}_{self.meta["array"].lower()}_'
@@ -357,6 +381,7 @@ class Imager:
             f'{self.meta["array"].lower()}_{self.meta["location"].lower()}_fisheye.{movie_container}'
         )
         movie_save_path = image_save_dir.parents[1] / self.animation_name
+
         # If the image directory exists we need to first remove all of the images to avoid
         # animating images from different method calls.
         if image_save_dir.is_dir():
@@ -378,6 +403,11 @@ class Imager:
             ax.axis('off')
             # Use an underscore so the original method parameters are not overwritten.
             _color_map, _color_norm = self._plot_params(image, color_bounds, color_map, color_norm)
+            
+            if len(self.meta['resolution']) == 3:  # tests if rgb
+                image = self._rgb_replacer(image)
+                if color_brighten:
+                    image = image / np.max(image)
 
             im = ax.imshow(image, cmap=_color_map, norm=_color_norm, origin='lower')
             if label:
@@ -411,6 +441,7 @@ class Imager:
         color_map: str = None,
         color_bounds: List[float] = None,
         color_norm: str = None,
+        color_brighten: bool = True,
         min_elevation: float = 10,
         asi_label: bool = True,
         pcolormesh_kwargs: dict = {},
@@ -438,6 +469,14 @@ class Imager:
             The ocean color. If None will not draw it.
         color_map: str
             The matplotlib colormap to use. See `matplotlib colormaps <https://matplotlib.org/stable/tutorials/colors/colormaps.html>`_.
+        color_norm: str
+            Set the 'lin' (linear) or 'log' (logarithmic) color normalization. If color_norm=None,
+            the color normalization will be taken from the ASI array (if specified), and if not
+            specified it will default to logarithmic. The norm is not applied to RGB images (see 
+            `matplotlib.pyplot.imshow <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html>`_)
+        color_brighten: bool
+            If True, scales the RGB intensities from min(image)-max(image) to 0-1 range. This 
+            results in brighter colors. This is only applied to RGB images.
         min_elevation: float
             Masks the pixels below min_elevation degrees.
         asi_label: bool
@@ -493,12 +532,14 @@ class Imager:
         color_map, color_norm = self._plot_params(image, color_bounds, color_map, color_norm)
 
         ax, p, _ = self._plot_mapped_image(
-            ax, image, min_elevation, color_map, color_norm, asi_label, pcolormesh_kwargs
+            ax, image, min_elevation, color_map, color_norm, color_brighten, asi_label, 
+            pcolormesh_kwargs
         )
         return ax, p
 
     def _plot_mapped_image(
-        self, ax, image, min_elevation, color_map, color_norm, asi_label, pcolormesh_kwargs
+        self, ax, image, min_elevation, color_map, color_norm, color_brighten, asi_label, 
+        pcolormesh_kwargs
     ):
         """
         Plot the image onto a geographic map using the modified version of plt.pcolormesh.
@@ -521,6 +562,7 @@ class Imager:
             ax,
             cmap=color_map,
             norm=color_norm,
+            color_brighten=color_brighten,
             pcolormesh_kwargs=pcolormesh_kwargs_copy,
         )
 
@@ -562,7 +604,11 @@ class Imager:
         color_norm: str
             Set the 'lin' (linear) or 'log' (logarithmic) color normalization. If color_norm=None,
             the color normalization will be taken from the ASI array (if specified), and if not
-            specified it will default to logarithmic.
+            specified it will default to logarithmic. The norm is not applied to RGB images (see 
+            `matplotlib.pyplot.imshow <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html>`_)
+        color_brighten: bool
+            If True, scales the RGB intensities from min(image)-max(image) to 0-1 range. This 
+            results in brighter colors. This is only applied to RGB images.
         azel_contours: bool
             Superpose azimuth and elevation contours on or off.
         azel_contour_color: str
@@ -614,10 +660,12 @@ class Imager:
         color_map: str = None,
         color_bounds: List[float] = None,
         color_norm: str = None,
+        color_brighten: bool = True,
         min_elevation: float = 10,
         pcolormesh_kwargs: dict = {},
         asi_label: bool = True,
         movie_container: str = 'mp4',
+        animation_save_dir: Union[pathlib.Path, str]=None,
         ffmpeg_params={},
         overwrite: bool = False,
     ) -> Generator[
@@ -659,7 +707,11 @@ class Imager:
         color_norm: str
             Set the 'lin' (linear) or 'log' (logarithmic) color normalization. If color_norm=None,
             the color normalization will be taken from the ASI array (if specified), and if not
-            specified it will default to logarithmic.
+            specified it will default to logarithmic. The norm is not applied to RGB images (see 
+            `matplotlib.pyplot.imshow <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html>`_)
+        color_brighten: bool
+            If True, scales the RGB intensities from min(image)-max(image) to 0-1 range. This 
+            results in brighter colors. This is only applied to RGB images.
         min_elevation: float
             Masks the pixels below min_elevation degrees.
         pcolormesh_kwargs: dict
@@ -730,13 +782,18 @@ class Imager:
             )
         # Create the animation directory inside asilib.config['ASI_DATA_DIR'] if it does
         # not exist.
+        if animation_save_dir is None:
+            _path = asilib.config['ASI_DATA_DIR']
+        else:
+            _path = animation_save_dir
         image_save_dir = pathlib.Path(
-            asilib.config['ASI_DATA_DIR'],
+            _path,
             'animations',
             'images',
             f'{self.file_info["time_range"][0].strftime("%Y%m%d_%H%M%S")}_{self.meta["array"].lower()}_'
             f'{self.meta["location"].lower()}_map',
         )
+
         self.animation_name = (
             f'{self.file_info["time_range"][0].strftime("%Y%m%d_%H%M%S")}_'
             f'{self.file_info["time_range"][-1].strftime("%H%M%S")}_'
@@ -760,7 +817,8 @@ class Imager:
             _color_map, _color_norm = self._plot_params(image, color_bounds, color_map, color_norm)
 
             ax, pcolormesh_obj, label_obj = self._plot_mapped_image(
-                ax, image, min_elevation, _color_map, _color_norm, asi_label, pcolormesh_kwargs
+                ax, image, min_elevation, _color_map, _color_norm, color_brighten, asi_label, 
+                pcolormesh_kwargs
             )
 
             # Give the user the control of the subplot, image object, and return the image time
@@ -904,6 +962,7 @@ class Imager:
         color_map: str = None,
         color_bounds: List[float] = None,
         color_norm: str = None,
+        color_brighten: bool = True,
         pcolormesh_kwargs={},
     ) -> Tuple[plt.Axes, matplotlib.collections.QuadMesh]:
         """
@@ -934,7 +993,11 @@ class Imager:
         color_norm: str
             Set the 'lin' (linear) or 'log' (logarithmic) color normalization. If color_norm=None,
             the color normalization will be taken from the ASI array (if specified), and if not
-            specified it will default to logarithmic.
+            specified it will default to logarithmic. The norm is not applied to RGB images (see 
+            `matplotlib.pyplot.imshow <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html>`_)
+        color_brighten: bool
+            If True, scales the RGB intensities from min(image)-max(image) to 0-1 range. This 
+            results in brighter colors. This is only applied to RGB images.
         pcolormesh_kwargs: dict
             A dictionary of keyword arguments (kwargs) to pass directly into
             plt.pcolormesh.
@@ -985,10 +1048,16 @@ class Imager:
 
         _color_map, _color_norm = self._plot_params(_keogram, color_bounds, color_map, color_norm)
 
+        # Same as transpose, but correctly handles RGB keograms.
+        _keogram = np.swapaxes(_keogram, 1, 0)
+        if len(_keogram.shape) == 3 and color_brighten:
+            # To see the RGB intensities clearly, the channel intensities need to span 0-1.
+            _keogram = _keogram / np.max(_keogram)
+
         pcolormesh_obj = ax.pcolormesh(
             _keogram_time,
             _geogram_lat,
-            _keogram[:-1, :-1].T,
+            _keogram,
             norm=_color_norm,
             shading='auto',
             cmap=_color_map,
@@ -1007,13 +1076,9 @@ class Imager:
         """
         # CASE 1: No path provided. Output self._pixels that slice the meridian.
         if path is None:
-            self._pixels = np.column_stack(
-                (
-                    np.arange(self.meta['resolution'][0]),  # All y-axis indices
-                    # Slice half way in the x-axis (meridian)
-                    np.full((self.meta['resolution'][1]), self.meta['resolution'][1] // 2),
-                )
-            ).astype(int)
+            self._pixels = -1*np.ones((self.meta['resolution'][0], 2), dtype=int)
+            self._pixels[:, 0] = np.arange(self.meta['resolution'][0])
+            self._pixels[:, 1] = int(self.meta['resolution'][1] // 2)
 
         # CASE 2: A path is provided so now we need to calculate the custom path
         # on the lat/lon skymap.
@@ -1272,31 +1337,6 @@ class Imager:
                     yield time_chunk[idt], image_chunk[idt]
         return
 
-    # def iter_chunks(self, chunk_size: int) -> Union[np.array, np.array]:
-    #     """
-    #     Chunk and iterate over the ASI data. The output data is
-    #     clipped by time_range.
-
-    #     Parameters
-    #     ----------
-    #     chunk_size: int
-    #         The number of time stamps and images to return.
-
-    #     Yields
-    #     ------
-    #     np.array:
-    #         ASI timestamps in datetine.datetime() or numpy.datetime64() format.
-    #     np.array:
-    #         ASI images.
-
-    #     Example
-    #     -------
-    #     TODO: Add
-    #     """
-    #     raise NotImplementedError
-
-    #     yield
-
     def _estimate_n_times(self):
         """
         Estimate the maximum number of time stamps for the Imager's time range.
@@ -1332,10 +1372,9 @@ class Imager:
                 self._times[start_idt : start_idt + file_times.shape[0]] = file_times
                 self._images[start_idt : start_idt + file_times.shape[0]] = file_images
                 start_idt += file_times.shape[0]
-            # Cut any unfilled times and images
-            valid_ind = np.where(~np.isnan(self._images[:, 0, 0]))[0]
-            self._times = self._times[valid_ind]
-            self._images = self._images[valid_ind]
+            # Remove any unfilled times and images
+            self._times = self._times[:start_idt]
+            self._images = self._images[:start_idt, ...].astype(int)
             return _img_data_type(self._times, self._images)
 
         elif 'time' in self.file_info.keys():
@@ -1598,6 +1637,14 @@ class Imager:
             _direction_pixels[i, :] = np.unravel_index(min_az_flat_array, self.skymap['az'].shape)
 
         _direction_pixels = _direction_pixels[~np.isnan(_direction_pixels[:, 0]), :]
+        # Points near the edge scew the cardinal direction from the true direction.
+        _not_near_edge = np.where(
+            (_direction_pixels[:, 0] < self.meta['resolution'][0]-1) & 
+            (_direction_pixels[:, 0] > 0) & 
+            (_direction_pixels[:, 1] < self.meta['resolution'][1]-1) & 
+            (_direction_pixels[:, 1] > 0)
+            )[0]
+        _direction_pixels = _direction_pixels[_not_near_edge, :]
         _direction_pixels = _direction_pixels.astype(int)
 
         # Calculate the pixels nerest and furthest away from zenith. This will define the rise
@@ -1633,12 +1680,13 @@ class Imager:
         lon_map_copy[idh] = np.nan
         lat_map_copy[idh] = np.nan
 
-        if image is not None:
-            image_copy = image.copy()
-            image_copy = image_copy.astype(float)  # Can't mask image unless it is a float array.
-            image_copy[idh] = np.nan
-        else:
-            image_copy = None
+        # if image is not None:
+        #     image_copy = image.copy()
+        #     original_dtype = image.dtype
+        #     image_copy = image_copy.astype(float)  # Can't mask image unless it is a float array.
+        #     image_copy[idh] = np.nan
+        # else:
+        #     image_copy = None
 
         if (lon_map.shape[0] == el_map.shape[0] + 1) and (lon_map.shape[1] == el_map.shape[1] + 1):
             # TODO: This is REGO/THEMIS specific. Remove here and add this to the themis() function?
@@ -1654,7 +1702,7 @@ class Imager:
             lat_map_copy[idh_boundary_bottom] = np.nan
             lon_map_copy[idh_boundary_right] = np.nan
             lat_map_copy[idh_boundary_right] = np.nan
-        return lon_map_copy, lat_map_copy, image_copy
+        return lon_map_copy, lat_map_copy, image
 
     def _create_animation(
         self,
@@ -1712,14 +1760,41 @@ class Imager:
         )
         return f'{self.__class__.__qualname__}(' + params + ')'
 
+    def _rgb_replacer(self, image):
+
+        #https://www.tutorialspoint.com/How-to-check-if-a-string-only-contains-certain-characters-in-Python
+
+        if set(self.meta['colors']).issubset('rgb'): #Checks if the colors selected are a subset of 'rgb', if there is a character not 'r' 'g' or 'b', it will raise an error
+            pass
+        else:
+            raise ValueError(" The only valid characters for the colors kwarg are 'r', 'g', 'b' ")
+        
+        if (*self.meta['colors'],) == ['r', 'g', 'b ']: #Passes colour removal if all colors are present, no logic required
+            pass
+
+        else:
+            # tests if color is selected, if not selected, then add nan values to array in lieu of color
+            if 'r' not in (*self.meta['colors'],):
+                # takes the shape of c, excluding the last index (-1) and replaces that matrix with nans
+                image[:, :, 0] = np.full(np.shape(image)[:-1], np.nan)
+
+            if 'g' not in (*self.meta['colors'],):
+                image[:, :, 1] = np.full(np.shape(image)[:-1], np.nan)
+
+            if 'b' not in (*self.meta['colors'],):
+                image[:, :, 2] = np.full(
+                    np.shape(image)[:-1], np.nan)
+        return image
+
     def _pcolormesh_nan(
         self,
         x: np.ndarray,
         y: np.ndarray,
-        c: np.ndarray,
+        image: np.ndarray,
         ax,
         cmap=None,
         norm=None,
+        color_brighten: bool = True,
         pcolormesh_kwargs={},
     ):
         """
@@ -1770,12 +1845,16 @@ class Imager:
         # Same, but for the rows below bottom.
         x[bottom:, :] = np.nanmax(x[bottom, :])
         y[bottom:, :] = np.nanmax(y[bottom, :])
-
-        # old masked c code: np.ma.masked_where(~mask[:-1, :-1], c)[::-1, ::-1]
+        
+        if len(self.meta['resolution']) == 3: #tests to see if the colors selected for an rgb image are rgb or rb or something else
+            image = self._rgb_replacer(image)
+            if color_brighten:
+                image = image / np.max(image)
+            
         p = ax.pcolormesh(
             x,
             y,
-            c,
+            image,
             cmap=cmap,
             shading='auto',
             norm=norm,
