@@ -3,8 +3,10 @@ Tests the asilib's Conjunction class.
 """
 from datetime import datetime, timedelta
 import dateutil.parser
+import string
 
 import matplotlib.pyplot as plt
+import matplotlib.gridspec as gridspec
 import matplotlib.testing.decorators
 import pandas as pd
 import pytest
@@ -289,7 +291,33 @@ def test_plot_interp_sat_wrap():
 
 @pytest.mark.skipif(not irbem_imported, reason='IRBEM is not installed.')
 def test_magnetic_tracing():
-    raise AssertionError
+    location = 'ATHA'
+    dt = 10  # seconds
+    time_range = (datetime(2020, 1, 1, 0, 0, 0), datetime(2020, 1, 1, 0, 1, 0))
+    asi = asilib.asi.fake_asi.fake_asi(location, time_range=time_range)
+
+    n = int((time_range[1]-time_range[0]).total_seconds()//dt)
+    sat_time = np.array([time_range[0] + timedelta(seconds=i*dt) 
+                         for i in range(n)])
+    lats = np.linspace(asi.meta['lat'] - 2, asi.meta['lat'] + 2, num=sat_time.shape[0])
+    lons = np.linspace(asi.meta['lon'] - 2, asi.meta['lon'] + 2, num=sat_time.shape[0])
+    sat_lla = np.stack((lats, lons, 500 * np.ones_like(lons))).T
+    c = asilib.Conjunction(asi, (sat_time, sat_lla))
+
+    c.lla_footprint(110)
+    
+    assert np.all(c.sat.index == sat_time)
+    np.testing.assert_almost_equal(c.sat['alt'], 110*np.ones_like(c.sat['alt']), decimal=1)
+    np.testing.assert_almost_equal(
+        c.sat['lat'],
+        np.array([53.63169896, 54.39262177, 55.1545005 , 55.91733138, 56.68123125,
+            57.44607773])
+    )
+    np.testing.assert_almost_equal(
+        c.sat['lon'],
+        np.array([-114.9137138, -114.12793  , -113.342572 , -112.5576476,
+            -111.7731121, -110.9890267])
+    )
     return
 
 
@@ -469,6 +497,60 @@ def test_intensity_closest_pixel():
     )
     return
 
+@matplotlib.testing.decorators.image_comparison(
+    baseline_images=['test_rgb_intensity_closest_pixel'],
+    tol=10,
+    remove_text=True,
+    extensions=['png'],
+)
+def test_rgb_intensity_closest_pixel():
+    """
+    Test the RGB auroral intensity from the nearest pixel.
+    """
+    time_range = (datetime(2021, 11, 4, 7, 2, 0), datetime(2021, 11, 4, 7, 4, 0))
+    location_code = 'LUCK'
+    alt = 110
+
+    asi = asilib.asi.trex_rgb(location_code, time_range=time_range, alt=alt)
+
+    # Create a orbit with a footprint every 5 seconds.
+    dt_sat = 5
+    n_sat_times = int((time_range[1]-time_range[0]).total_seconds()//dt_sat)
+    sat_times = np.array([time_range[0]+timedelta(seconds=dt_sat*i) for i in range(n_sat_times)])
+    lats = np.linspace(asi.meta['lat']-3, asi.meta['lat']+3, num=n_sat_times)
+    lons = (asi.meta['lon']-2) * np.linspace(1.02, 0.98, num=n_sat_times)
+    alts = alt * np.ones_like(lats)
+    lla = np.stack((lats, lons, alts)).T
+
+    c = asilib.Conjunction(asi, (sat_times, lla))
+    intensity = c.intensity()
+
+    plot_n_times = 4
+    fig = plt.figure(figsize=(3*plot_n_times, 6))
+    gs = gridspec.GridSpec(2, plot_n_times)
+    ax = [fig.add_subplot(gs[0, i]) for i in range(plot_n_times)]
+    bx = fig.add_subplot(gs[1, :])
+    dt_plot = int((time_range[1]-time_range[0]).total_seconds()//plot_n_times)
+
+    for i, ax_i in enumerate(ax):
+        t_i = time_range[0] + timedelta(seconds=(i+0.5)*dt_plot)
+        asi_image = asi[t_i]
+        asi_image.plot_map(ax=ax_i)
+        ax_i.text(
+            0, 0.99, f'({string.ascii_uppercase[i]}) {asi_image.file_info["time"]}', 
+            transform=ax_i.transAxes, va='top', fontsize=12,
+            bbox=dict(facecolor='white', edgecolor='red', pad=0.01),
+            )
+        ax_i.plot(lla[:, 1], lla[:, 0], c='r', ls=':')
+
+        idt_min = np.argmin(np.abs([sat_time_i - t_i for sat_time_i in sat_times]))
+        ax_i.scatter(lla[idt_min, 1], lla[idt_min, 0], c='r', marker='x')
+        bx.axvline(sat_times[idt_min], c='k')
+
+    for color, _intensity in zip(['r', 'g', 'b'], intensity.T):
+        bx.plot(c.sat.index, _intensity, c=color)
+    fig.tight_layout()
+    return
 
 def test_intensity_area():
     """
@@ -567,3 +649,58 @@ def test_intensity_area():
         )
     )
     return
+
+@matplotlib.testing.decorators.image_comparison(
+    baseline_images=['test_rgb_intensity_area'],
+    tol=10,
+    remove_text=True,
+    extensions=['png'],
+)
+def test_rgb_intensity_area():
+    """
+    Test the RGB auroral intensity in a (10, 10) km area.
+    """
+    time_range = (datetime(2021, 11, 4, 7, 2, 0), datetime(2021, 11, 4, 7, 4, 0))
+    location_code = 'LUCK'
+    alt = 110
+
+    asi = asilib.asi.trex_rgb(location_code, time_range=time_range, alt=alt)
+
+    # Create a orbit with a footprint every 5 seconds.
+    dt_sat = 5
+    n_sat_times = int((time_range[1]-time_range[0]).total_seconds()//dt_sat)
+    sat_times = np.array([time_range[0]+timedelta(seconds=dt_sat*i) for i in range(n_sat_times)])
+    lats = np.linspace(asi.meta['lat']-3, asi.meta['lat']+3, num=n_sat_times)
+    lons = (asi.meta['lon']-2) * np.linspace(1.02, 0.98, num=n_sat_times)
+    alts = alt * np.ones_like(lats)
+    lla = np.stack((lats, lons, alts)).T
+
+    c = asilib.Conjunction(asi, (sat_times, lla))
+    intensity = c.intensity(box=(10,10))
+
+    plot_n_times = 4
+    fig = plt.figure(figsize=(3*plot_n_times, 6))
+    gs = gridspec.GridSpec(2, plot_n_times)
+    ax = [fig.add_subplot(gs[0, i]) for i in range(plot_n_times)]
+    bx = fig.add_subplot(gs[1, :])
+    dt_plot = int((time_range[1]-time_range[0]).total_seconds()//plot_n_times)
+
+    for i, ax_i in enumerate(ax):
+        t_i = time_range[0] + timedelta(seconds=(i+0.5)*dt_plot)
+        asi_image = asi[t_i]
+        asi_image.plot_map(ax=ax_i)
+        ax_i.text(
+            0, 0.99, f'({string.ascii_uppercase[i]}) {asi_image.file_info["time"]}', 
+            transform=ax_i.transAxes, va='top', fontsize=12,
+            bbox=dict(facecolor='white', edgecolor='red', pad=0.01),
+            )
+        ax_i.plot(lla[:, 1], lla[:, 0], c='r', ls=':')
+
+        idt_min = np.argmin(np.abs([sat_time_i - t_i for sat_time_i in sat_times]))
+        ax_i.scatter(lla[idt_min, 1], lla[idt_min, 0], c='r', marker='x')
+        bx.axvline(sat_times[idt_min], c='k')
+
+    for color, _intensity in zip(['r', 'g', 'b'], intensity.T):
+        bx.plot(c.sat.index, _intensity, c=color)
+    fig.tight_layout()
+    return
\ No newline at end of file
